@@ -1127,15 +1127,9 @@ sub txt_fill { # pre1, base, "text to be formatted"
 	}
 	# check for a item in describe etc
 	if ($para =~ s/^[\n]*\.tide ([^\n]+)\n//) {
-	    my $short = length($indent) + $INDENTDD - length($1);
-	    if ($short >= 0) {
-		$indent1 = " " x $short . $1;
-	    } else {
-		$indent1 = "  " . $1;
-		$para = "\\cr ". $para;
-	    }    
-	    $indent2 = $indent . (" " x $INDENTDD);    
-	}
+	    $indent1 = " " x $INDENT . txt_header($1);
+	    $indent2 = $indent . (" " x $INDENTDD);
+	}	
         # check for .in or .inen command
 	if ($para =~ s/^[\n]*\.in([^\ ]*) (.*)/\2/) {
 	    $INDENT = $INDENT + $para;
@@ -2048,8 +2042,10 @@ sub latex_code_trans {
 	$c =~ s/\\\\/$BSL/go;
 	$c =~ s/\\([$LATEX_SPECIAL])/$1/go; #- unescape them (should not be escaped)
 	$c =~ s/[$LATEX_SPECIAL]/\\$&/go; #- escape them
-	$c =~ s/\\\^/\$\\,\\hat{\\,}\$/go;# ^ is SPECIAL
-	$c =~ s/\\~/\$\\,\\tilde{\\,}\$/go;
+#	$c =~ s/\\\^/\$\\,\\hat{\\,}\$/go;# ^ is SPECIAL
+#	$c =~ s/\\~/\$\\,\\tilde{\\,}\$/go;
+	$c =~ s/\\\^/\\textasciicircum{}/go;# ^ is SPECIAL
+	$c =~ s/\\~/\\textasciitilde{}/go;
 	$c =~ s/$BSL/\\bsl{}/go;
     }
     ## avoid conversion to guillemots
