@@ -97,7 +97,7 @@ c     fortran dabs,dmax1,max0,min0,mod,dsqrt
 c
       subroutine dsvdc(x,ldx,n,p,s,e,u,ldu,v,ldv,work,job,info)
       integer ldx,n,p,ldu,ldv,job,info
-      double precision x(ldx,1),s(1),e(1),u(ldu,1),v(ldv,1),work(1)
+      double precision x(ldx,*),s(*),e(*),u(ldu,*),v(ldv,*),work(*)
 c
 c     internal variables
 c
@@ -108,6 +108,11 @@ c
      *                 smm1,t1,test,ztest
       logical wantu,wantv
 c
+c     unnecessary initializations of l and ls to keep g77 -Wall happy
+c
+      l = 0
+      ls = 0
+c
 c
 c     set the maximum number of iterations.
 c
