@@ -1,7 +1,7 @@
 /*
  *  R : A Computer Language for Statistical Data Analysis
  *  Copyright (C) 1995, 1996  Robert Gentleman and Ross Ihaka
- *  Copyright (C) 1999, The R Development Core Team.
+ *  Copyright (C) 1999-2000   The R Development Core Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,12 +21,12 @@
 #ifndef _R_INTERNALS_H_
 #define _R_INTERNALS_H_
 
-#include "Arith.h"		/*-> Rconfig.h */
-#include "Complex.h"
-#include "Errormsg.h"
-#include "Memory.h"
-#include "PrtUtil.h"
-#include "Utils.h"
+#include "R_ext/Arith.h"
+#include "R_ext/Complex.h"
+#include "R_ext/Error.h"
+#include "R_ext/Memory.h"
+#include "R_ext/PrtUtil.h"
+#include "R_ext/Utils.h"
 
 #include <errno.h>
 #include <stdio.h>
@@ -37,16 +37,6 @@
 #include <limits.h>
 #include <float.h>
 #include <ctype.h>
-#ifdef PSIGNAL
-#include <psignal.h>
-#else
-#include <signal.h>
-#include <setjmp.h>
-#endif
-#include <time.h>
-#ifdef HAVE_LOCALE_H
-#include <locale.h>
-#endif
 
 #ifdef __MAIN__
 #define extern
@@ -221,6 +211,8 @@ extern SEXP	R_MissingArg;	    /* Missing argument marker */
 /* Symbol Table Shortcuts */
 extern SEXP	R_Bracket2Symbol;   /* "[[" */
 extern SEXP	R_BracketSymbol;    /* "[" */
+extern SEXP	R_BraceSymbol;      /* "{" */
+extern SEXP	R_TmpvalSymbol;     /* "*tmp*" */
 extern SEXP	R_ClassSymbol;	    /* "class" */
 extern SEXP	R_DimNamesSymbol;   /* "dimnames" */
 extern SEXP	R_DimSymbol;	    /* "dim" */
@@ -237,13 +229,169 @@ extern SEXP	R_TspSymbol;	    /* "tsp" */
 extern SEXP	R_LastvalueSymbol;  /* ".Last.value" */
 extern SEXP	R_CommentSymbol;    /* "comment" */
 extern SEXP	R_SourceSymbol;     /* "source" */
+extern SEXP	R_DotEnvSymbol;     /* ".Environment" */
 
 /* Missing Values - others from Arith.h */
+#define NA_STRING	R_NaString
 extern SEXP	R_NaString;	    /* NA_STRING as a CHARSXP */
 extern SEXP	R_BlankString;	    /* "" as a CHARSXP */
 
 /*--- FUNCTIONS ------------------------------------------------------ */
 
+#ifndef R_NO_REMAP
+#define allocArray		Rf_allocArray
+#define allocList		Rf_allocList
+#define allocMatrix		Rf_allocMatrix
+#define allocSExp		Rf_allocSExp
+#define allocString		Rf_allocString
+#define allocVector		Rf_allocVector
+#define append			Rf_append
+#define applyClosure		Rf_applyClosure
+#define arraySubscript		Rf_arraySubscript
+#define asChar			Rf_asChar
+#define asComplex		Rf_asComplex
+#define asInteger		Rf_asInteger
+#define asLogical		Rf_asLogical
+#define asReal			Rf_asReal
+#define coerceList		Rf_coerceList
+#define coerceVector		Rf_coerceVector
+#define CoercionWarning		Rf_CoercionWarning
+#define ComplexFromInteger	Rf_ComplexFromInteger
+#define ComplexFromLogical	Rf_ComplexFromLogical
+#define ComplexFromReal		Rf_ComplexFromReal
+#define ComplexFromString	Rf_ComplexFromString
+#define conformable		Rf_conformable
+#define cons			Rf_cons
+#define copyListMatrix		Rf_copyListMatrix
+#define copyMatrix		Rf_copyMatrix
+#define copyMostAttrib		Rf_copyMostAttrib
+#define copyVector		Rf_copyVector
+#define CreateTag		Rf_CreateTag
+#define CustomPrintValue	Rf_CustomPrintValue
+#define defineVar		Rf_defineVar
+#define dimgets			Rf_dimgets
+#define dimnamesgets		Rf_dimnamesgets
+#define duplicate		Rf_duplicate
+#define elt			Rf_elt
+#define emptyEnv		Rf_emptyEnv
+#define EnsureString		Rf_EnsureString
+#define errorcall		Rf_errorcall
+#define ErrorMessage		Rf_ErrorMessage
+#define eval			Rf_eval
+#define EvalArgs		Rf_EvalArgs
+#define evalList		Rf_evalList
+#define evalListKeepMissing	Rf_evalListKeepMissing
+#define findFun			Rf_findFun
+#define findVar			Rf_findVar
+#define GetArrayDimnames	Rf_GetArrayDimnames
+#define getAttrib		Rf_getAttrib
+#define GetColNames		Rf_GetColNames
+#define GetMatrixDimnames	Rf_GetMatrixDimnames
+#define GetOption		Rf_GetOption
+#define GetOptionDigits		Rf_GetOptionDigits
+#define GetOptionWidth		Rf_GetOptionWidth
+#define GetPar			Rf_GetPar
+#define GetRowNames		Rf_GetRowNames
+#define gsetVar			Rf_gsetVar
+#define inherits		Rf_inherits
+#define install			Rf_install
+#define IntegerFromComplex	Rf_IntegerFromComplex
+#define IntegerFromLogical	Rf_IntegerFromLogical
+#define IntegerFromReal		Rf_IntegerFromReal
+#define IntegerFromString	Rf_IntegerFromString
+#define isArray			Rf_isArray
+#define isComplex		Rf_isComplex
+#define isEnvironment		Rf_isEnvironment
+#define isExpression		Rf_isExpression
+#define isExpressionObject	Rf_isExpressionObject
+#define isFactor		Rf_isFactor
+#define isFrame			Rf_isFrame
+#define isFree			Rf_isFree
+#define isFunction		Rf_isFunction
+#define isInteger		Rf_isInteger
+#define isLanguage		Rf_isLanguage
+#define isList			Rf_isList
+#define isLogical		Rf_isLogical
+#define isMatrix		Rf_isMatrix
+#define isNewList		Rf_isNewList
+#define isNull			Rf_isNull
+#define isNumeric		Rf_isNumeric
+#define isObject		Rf_isObject
+#define isOrdered		Rf_isOrdered
+#define isPairList		Rf_isPairList
+#define isReal			Rf_isReal
+#define isString		Rf_isString
+#define isSymbol		Rf_isSymbol
+#define isTs			Rf_isTs
+#define isUnordered		Rf_isUnordered
+#define isUserBinop		Rf_isUserBinop
+#define isValidString		Rf_isValidString
+#define isValidStringF		Rf_isValidStringF
+#define isVector		Rf_isVector
+#define isVectorAtomic		Rf_isVectorAtomic
+#define isVectorizable		Rf_isVectorizable
+#define isVectorList		Rf_isVectorList
+#define ItemName		Rf_ItemName
+#define lang1			Rf_lang1
+#define lang2			Rf_lang2
+#define lang3			Rf_lang3
+#define lang4			Rf_lang4
+#define lastElt			Rf_lastElt
+#define lcons			Rf_lcons
+#define length(x)		Rf_length(x)
+#define lengthgets		Rf_lengthgets
+#define list1			Rf_list1
+#define list2			Rf_list2
+#define list3			Rf_list3
+#define list4			Rf_list4
+#define listAppend		Rf_listAppend
+#define LogicalFromComplex	Rf_LogicalFromComplex
+#define LogicalFromInteger	Rf_LogicalFromInteger
+#define LogicalFromReal		Rf_LogicalFromReal
+#define LogicalFromString	Rf_LogicalFromString
+#define makeSubscript		Rf_makeSubscript
+#define matchArg		Rf_matchArg
+#define matchArgs		Rf_matchArgs
+#define matchPar		Rf_matchPar
+#define mkChar			Rf_mkChar
+#define mkString		Rf_mkString
+#define namesgets		Rf_namesgets
+#define ncols			Rf_ncols
+#define nlevels			Rf_nlevels
+#define NonNullStringMatch	Rf_NonNullStringMatch
+#define nrows			Rf_nrows
+#define nthcdr			Rf_nthcdr
+#define PairToVectorList	Rf_PairToVectorList
+#define pmatch			Rf_pmatch
+#define PrintDefaults		Rf_PrintDefaults
+#define PrintValue		Rf_PrintValue
+#define PrintValueEnv		Rf_PrintValueEnv
+#define PrintValueRec		Rf_PrintValueRec
+#define protect			Rf_protect
+#define RealFromComplex		Rf_RealFromComplex
+#define RealFromInteger		Rf_RealFromInteger
+#define RealFromLogical		Rf_RealFromLogical
+#define RealFromString		Rf_RealFromString
+#define rownamesgets		Rf_rownamesgets
+#define ScalarComplex		Rf_ScalarComplex
+#define ScalarInteger		Rf_ScalarInteger
+#define ScalarLogical		Rf_ScalarLogical
+#define ScalarReal		Rf_ScalarReal
+#define ScalarString		Rf_ScalarString
+#define setAttrib		Rf_setAttrib
+#define setSVector		Rf_setSVector
+#define setVar			Rf_setVar
+#define StringBlank		Rf_StringBlank
+#define StringFromComplex	Rf_StringFromComplex
+#define StringFromInteger	Rf_StringFromInteger
+#define StringFromLogical	Rf_StringFromLogical
+#define StringFromReal		Rf_StringFromReal
+#define substitute		Rf_substitute
+#define unprotect		Rf_unprotect
+#define unprotect_ptr		Rf_unprotect_ptr
+#define VectorToPairList	Rf_VectorToPairList
+#endif
+
 /* Type Coercions of all kinds */
 
 SEXP coerceVector(SEXP, SEXPTYPE);
@@ -333,6 +481,7 @@ int isExpression(SEXP);
 int isExpressionObject(SEXP);
 int isFactor(SEXP);
 int isFrame(SEXP);
+int isFree(SEXP);
 int isFunction(SEXP);
 int isInteger(SEXP);
 int isLanguage(SEXP);
@@ -365,6 +514,7 @@ SEXP lang4(SEXP, SEXP, SEXP, SEXP);
 SEXP lastElt(SEXP);
 SEXP lcons(SEXP, SEXP);
 int length(SEXP);
+SEXP lengthgets(SEXP, int);
 SEXP list1(SEXP);
 SEXP list2(SEXP, SEXP);
 SEXP list3(SEXP, SEXP, SEXP);
@@ -402,6 +552,10 @@ SEXP substitute(SEXP,SEXP);
 void unprotect(int);
 void unprotect_ptr(SEXP);
 
+				/* return(.) NOT reached : for -Wall */
+#define error_return(msg)	{ error(msg);		return R_NilValue; }
+#define errorcall_return(cl,msg){ errorcall(cl, msg);	return R_NilValue; }
+
 #ifdef __MAIN__
 #undef extern
 #endif
