@@ -5,12 +5,12 @@ contrasts <-
 	stop("contrasts apply only to factors")
     ctr <- attr(x, "contrasts")
     if (is.null(ctr)) {
-	ctr <- get(options("contrasts")[[1]] [[if (is.ordered(x)) 2 else 1]])(levels(x), contrasts = contrasts)
+	ctr <- get(getOption("contrasts")[[if (is.ordered(x)) 2 else 1]])(levels(x), contrasts = contrasts)
 	dimnames(ctr) <- list(levels(x), dimnames(ctr)[[2]])
     }
     else if (is.character(ctr))
 	ctr <- get(ctr)(levels(x), contrasts = contrasts)
-    if(ncol(ctr)==1) dimnames(ctr) <- list(dimnames(ctr)[[1]], "")
+    #if(ncol(ctr)==1) dimnames(ctr) <- list(dimnames(ctr)[[1]], "")
     ctr
 }
 
