@@ -72,7 +72,7 @@ help.search <- function(topic, fields = c("name", "title"),
                 cfile <- system.file("CONTENTS", pkg = p, lib = lib)
                 if(cfile != "") {
                     ctext <- scan("", file = cfile, sep = "\n",
-                                  quiet = TRUE)
+                                  quote="", quiet = TRUE)
                     if(length(ctext) > 0) {
                         ctext <- parse.dcf(ctext,
                                            fields = c("Entry", "Aliases",
@@ -111,7 +111,7 @@ help.search <- function(topic, fields = c("name", "title"),
     fields <- paste(fields, collapse = " or ")
     if (NROW(db) > 0) {
         FILE <- tempfile()
-        cat(paste("Objects with ", fields, " matching `", topic,
+        cat(paste("Help files with ", fields, " matching `", topic,
                   "':\n\n", sep = ""),
             file = FILE)
         dbnam <- paste(db[ , "name"], "(", db[, "pkg"], ")", sep = "")
@@ -120,7 +120,7 @@ help.search <- function(topic, fields = c("name", "title"),
             sep = "\n", file = FILE, append = TRUE)
         file.show(FILE, delete.file = TRUE)
     } else {
-        cat(paste("No objects found with ", fields, " matching `",
+        cat(paste("No help files found with ", fields, " matching `",
                   topic, "'\n", sep = ""))
     }
 
