@@ -69,7 +69,6 @@ lm <- function (formula, data = list(), subset, weights, na.action,
 lm.fit <- function (x, y, offset = NULL, method = "qr", tol = 1e-07, ...)
 {
     if (is.null(n <- nrow(x))) stop("'x' must be a matrix")
-    if (is.null(offset)) offset <- rep(0, NROW(y))
     p <- ncol(x)
     if (p == 0) {
         ## oops, null model
@@ -79,8 +78,10 @@ lm.fit <- function (x, y, offset = NULL, method = "qr", tol = 1e-07, ...)
     }
     ny <- NCOL(y)
     ## treat one-col matrix as vector
-    if ( is.matrix(y) && ny == 1 ) y <- drop(y)
-    y <- y - offset
+    if(is.matrix(y) && ny == 1)
+        y <- drop(y)
+    if(!is.null(offset))
+        y <- y - offset
     if (NROW(y) != n)
 	stop("incompatible dimensions")
     if(method != "qr")
@@ -102,7 +103,7 @@ lm.fit <- function (x, y, offset = NULL, method = "qr", tol = 1e-07, ...)
     coef <- z$coefficients
     pivot <- z$pivot
     r1 <- 1:z$rank
-    dn <- colnames(x)
+    dn <- colnames(x); if(is.null(dn)) dn <- paste("x", 1:p, sep="")
     nmeffects <- c(dn[pivot[r1]], rep("", n - z$rank))
     if (is.matrix(y)) {
 	coef[-r1, ] <- NA
@@ -116,8 +117,9 @@ lm.fit <- function (x, y, offset = NULL, method = "qr", tol = 1e-07, ...)
 	names(z$effects) <- nmeffects
     }
     z$coefficients <- coef
+    r1 <- y - z$residuals ; if(!is.null(offset)) r1 <- r1 + offset
     c(z[c("coefficients", "residuals", "effects", "rank")],
-      list(fitted.values= y + offset - z$residuals, assign= attr(x, "assign"),
+      list(fitted.values = r1, assign = attr(x, "assign"),
 	   qr = z[c("qr", "qraux", "pivot", "tol", "rank")],
 	   df.residual = n - z$rank))
 }
@@ -126,9 +128,11 @@ lm.wfit <- function (x, y, w, offset = NULL, method = "qr", tol = 1e-7, ...)
 {
     if(is.null(n <- nrow(x))) stop("'x' must be a matrix")
     ny <- NCOL(y)
-    if (is.null(offset)) offset <- rep(0, NROW(y))
     ## treat one-col matrix as vector
-    if ( is.matrix(y) && ny == 1 ) y <- drop(y)
+    if(is.matrix(y) && ny == 1)
+        y <- drop(y)
+    if(!is.null(offset))
+        y <- y - offset
     if (NROW(y) != n | length(w) != n)
 	stop("incompatible dimensions")
     if (any(w < 0 | is.na(w)))
@@ -139,7 +143,6 @@ lm.wfit <- function (x, y, w, offset = NULL, method = "qr", tol = 1e-7, ...)
     if(length(list(...)))
 	warning(paste("Extra arguments", deparse(substitute(...)),
 		      "are just disregarded."))
-    y <- y - offset
     x.asgn <- attr(x, "assign")# save
     zero.weights <- any(w == 0)
     if (zero.weights) {
@@ -176,7 +179,7 @@ lm.wfit <- function (x, y, w, offset = NULL, method = "qr", tol = 1e-7, ...)
     coef <- z$coefficients
     pivot <- z$pivot
     r1 <- 1:z$rank
-    dn <- colnames(x)
+    dn <- colnames(x); if(is.null(dn)) dn <- paste("x", 1:p, sep="")
     nmeffects <- c(dn[pivot[r1]], rep("", n - z$rank))
     if (is.matrix(y)) {
 	coef[-r1, ] <- NA
@@ -191,7 +194,7 @@ lm.wfit <- function (x, y, w, offset = NULL, method = "qr", tol = 1e-7, ...)
     }
     z$coefficients <- coef
     z$residuals <- z$residuals/wts
-    z$fitted.values <- (y - z$residuals)
+    z$fitted.values <- y - z$residuals
     z$weights <- w
     if (zero.weights) {
 	coef[is.na(coef)] <- 0
@@ -199,19 +202,20 @@ lm.wfit <- function (x, y, w, offset = NULL, method = "qr", tol = 1e-7, ...)
 	if (ny > 1) {
 	    save.r[ok, ] <- z$residuals
 	    save.r[nok, ] <- y0 - f0
-	    save.f[ok, ] <- z$fitted.values + offset[ok,]
-	    save.f[nok, ] <- f0 + offset[nok,]
+	    save.f[ok, ] <- z$fitted.values
+	    save.f[nok, ] <- f0
 	}
 	else {
 	    save.r[ok] <- z$residuals
 	    save.r[nok] <- y0 - f0
-	    save.f[ok] <- z$fitted.values + offset[ok]
-	    save.f[nok] <- f0 + offset[nok]
+	    save.f[ok] <- z$fitted.values
+	    save.f[nok] <- f0
 	}
 	z$residuals <- save.r
 	z$fitted.values <- save.f
 	z$weights <- save.w
-    } else
+    }
+    if(!is.null(offset))
         z$fitted.values <- z$fitted.values + offset
     c(z[c("coefficients", "residuals", "fitted.values", "effects",
 	  "weights", "rank")],
@@ -478,37 +482,39 @@ anovalist.lm <- function (object, ..., test = NULL)
 	      class= c("anova", "data.frame"))# was "tabular"
 }
 
-predict.lm <- function(object, newdata,
+## code from John Maindonald 26Jul2000
+"predict.lm" <- function(object, newdata,
 		       se.fit = FALSE, scale = NULL, df = Inf,
 		       interval=c("none","confidence","prediction"),
                        level=.95,  type=c("response","terms"),
                        terms=NULL, ...)
 {
-    attrassign <- function (object, ...) UseMethod("attrassign")
-    attrassign.lm <- function (lmobj)
-        attrassign(model.matrix(lmobj), terms(lmobj))
-    attrassign.default <- function (mmat, tt)
-    {
-        if (!inherits(tt, "terms"))
-            stop("need terms object")
-        aa <- attr(mmat, "assign")
-        if (is.null(aa))
-            stop("argument is not really a model matrix")
-        ll <- attr(tt, "term.labels")
-        if (attr(tt, "intercept") > 0)
-            ll <- c("(Intercept)", ll)
-        aaa <- factor(aa, labels = ll)
-        split(order(aa), aaa)
+## june 24 2000 (3 minor changes from JM's May 7 version)
+    attrassign<-function (object, ...) UseMethod("attrassign")
+    attrassign.lm<-function (lmobj)
+        attrassign(model.matrix(lmobj),terms(lmobj))
+    attrassign.default<-function (mmat, tt) {
+      if (!inherits(tt, "terms"))
+        stop("need terms object")
+      aa <- attr(mmat, "assign")
+      if (is.null(aa))
+        stop("argument is not really a model matrix")
+      ll <- attr(tt, "term.labels")
+      if (attr(tt, "intercept") > 0)
+        ll <- c("(Intercept)", ll)
+      aaa <- factor(aa, labels = ll)
+      split(order(aa), aaa)
     }
     tt <- terms(object)
     if(missing(newdata)) {
         X <- model.matrix(object)
         offset <- object$offset
-    } else {
-	X <- model.matrix(delete.response(tt), newdata,
+    }
+    else {
+        X <- model.matrix(delete.response(tt), newdata,
 			  contrasts = object$contrasts, xlev = object$xlevels)
 	offset <- if (!is.null(off.num<-attr(tt,"offset")))
-	    eval(attr(tt,"variables")[[off.num + 1]], newdata)
+	    eval(attr(tt,"variables")[[off.num+1]], newdata)
 	else if (!is.null(object$offset))
 	    eval(object$call$offset, newdata)
     }
@@ -516,11 +522,12 @@ predict.lm <- function(object, newdata,
     p <- object$rank
     p1 <- 1:p
     piv <- object$qr$pivot[p1]
-    est <- object$coefficients[piv]
-    predictor <- drop(X[, piv, drop = FALSE] %*% est)
+## NB: Q[p1,]%*%X[,piv]=R[p1,p1]
+    beta <- object$coefficients
+    predictor <- drop(X[, piv, drop = FALSE] %*% beta[piv])
     if ( !is.null(offset) ) predictor <- predictor + offset
     interval <- match.arg(interval)
-    type <- match.arg(type)
+    type<-match.arg(type)
     if(se.fit || interval != "none") {
 	if (is.null(scale)) {
 	    r <- resid(object)
@@ -532,84 +539,88 @@ predict.lm <- function(object, newdata,
 	} else {
 	    res.var <- scale^2
 	}
-
-        if (type != "terms"){
-            if(missing(newdata)) {
-                ip <- drop(qr.Q(object$qr)^2 %*%
-                           rep(res.var, length(object$qr$pivot)))
-            } else {
-                vcov <- res.var * chol2inv(object$qr$qr[p1, p1, drop = FALSE])
-                X1 <- X[, piv, drop = FALSE]
-                ip <- sapply(split(X1, row(X1)),
-                             function(xi) xi %*% vcov %*% xi)
-            }
+ ## type!="terms"   
+    if(type!="terms"){
+       if(missing(newdata))
+       XRinv<-qr.Q(object$qr)[,p1]
+       else {
+             Rinv<-qr.solve(qr.R(object$qr)[p1,p1])
+             XRinv<-X[,piv]%*%Rinv
+             }
+	ip<-drop(XRinv^2%*%rep(res.var,p))
 	}
     }
-    if (type == "terms"){
-        asgn <- attrassign(object)
-        beta <- coef(object)
-        hasintercept <- attr(tt,"intercept")>0
-        if (hasintercept)
-            asgn$"(Intercept)" <- NULL
-        nterms <- length(asgn)
-        predictor <- matrix(ncol=nterms,nrow=NROW(X))
-        dimnames(predictor) <- list(rownames(X),names(asgn))
+## type=="terms"   
+    if (type=="terms"){
+      asgn <- attrassign(object)
+      hasintercept<-attr(tt,"intercept")>0
+      if (hasintercept){
+        asgn$"(Intercept)"<-NULL
+        avx<-rep(1/n,n)%*%model.matrix(object)
+	termsconst<-sum(avx[piv]*beta[piv])
+	}
+      nterms<-length(asgn)
+      predictor<-matrix(ncol=nterms,nrow=NROW(X))
+      dimnames(predictor)<-list(rownames(X),names(asgn))
 
-        if (se.fit||interval!="none"){
-            ip <- matrix(ncol=nterms, nrow=NROW(X))
-            dimnames(ip) <- list(rownames(X), names(asgn))
-            Q <- qr.Q(object$qr)
-            #Rinv <- qr.solve(qr.R(object$qr))
-            Rinv <- chol2inv(qr.R(object$qr))
-            p2 <- dim(Rinv)[2]
-        }
-        if(hasintercept){
-            avii <- apply(X, 2, mean)
-            X <- sweep(X, 2, avii)
-        }
-        for (i in seq(1, nterms,length=nterms)){
-            ii <- piv[asgn[[i]]]
-            predictor[,i]  <- X[, ii, drop=FALSE] %*% (beta[ii])
+      if (se.fit||interval!="none"){
+        ip<-matrix(ncol=nterms,nrow=NROW(X))
+        dimnames(ip)<-list(rownames(X),names(asgn))
+	Rinv<-qr.solve(qr.R(object$qr)[p1,p1])
+      }
+if(hasintercept){
+      X<-sweep(X,2,avx)}
+      unpiv<-rep(0,NCOL(X))
+      unpiv[piv]<-p1
+## Predicted values will be set to 0 for any term that
+## corresponds to columns of the X-matrix that are
+## completely aliased with earlier columns.
+      for (i in seq(1,nterms,length=nterms)){
+        iipiv<-asgn[[i]]  # Columns of X, ith term
+	ii<-unpiv[iipiv]  # Corresponding rows of Rinv
+        iipiv[ii==0]<-0
+	if(any(iipiv)>0)
+	        predictor[,i]<-X[,iipiv,drop=F]%*%(beta[iipiv])
+		else predictor[,i]<-rep(0,NROW(predictor))
+        if (se.fit||interval!="none"){ 
+	  if(any(iipiv)>0)      
 
-            if (se.fit || interval != "none"){
-                ii2 <- asgn[[i]]
-                vci <- Rinv[ii2, ii2]*res.var
-                for(j in (1:NROW(X))){
-                    xi <- X[j, ii, drop=FALSE]
-                    ip[j,i] <- sum(xi%*% vci %*%t(xi))
-                }
-            }
+ip[,i]<-as.matrix(X[,iipiv,drop=F]%*%Rinv[ii,,drop=F])^2%*%rep(res.var,p)
+	  else ip[,i]<-rep(0,NROW(ip))
         }
+      }
 
-        if (!is.null(terms)){
-            predictor <- predictor[, terms, drop=FALSE]
-            if (se.fit)
-                ip <- ip[, terms, drop=FALSE]
-        }
-        attr(predictor, 'constant') <- if (hasintercept)
-            coef(object)["(Intercept)"] else 0
+      if (!is.null(terms)){
+
+        predictor<-predictor[,terms,drop=F]
+        if (se.fit)
+          ip<-ip[,terms,drop=F]
+
+      }
+      attr(predictor, 'constant') <- if (hasintercept) termsconst else 0
     }
-
+## Now construct elements of the list that will be returned
     if(interval != "none") {
 	tfrac <- qt((1 - level)/2,df)
 	w <- tfrac * switch(interval,
-			    confidence = sqrt(ip),
-			    prediction = sqrt(ip + res.var)
+			    confidence=sqrt(ip),
+			    prediction=sqrt(ip+res.var)
 			    )
-        if(type != "terms"){
-            predictor <- cbind(predictor, predictor + w %o% c(1,-1))
-            colnames(predictor) <- c("fit", "lwr", "upr")
-        }
-        else {
-            lwr <- predictor + w
-            upr <- predictor - w
-        }
+
+if(type!="terms"){
+	predictor <- cbind(predictor, predictor + w %o% c(1,-1))
+	colnames(predictor) <- c("fit","lwr","upr")
+}
+else {
+lwr<-predictor+w
+upr<-predictor-w
+}
     }
-    if(type == "terms" && interval != "none")
-	list(fit = predictor, se.fit = sqrt(ip), lwr=lwr, upr=upr,
+    if(type=="terms"&&interval!="none")
+	list(fit = predictor, se.fit = sqrt(ip), lwr=lwr,upr=upr,
 	     df = df, residual.scale = sqrt(res.var))
     else if (se.fit)
-        list(fit = predictor, se.fit = sqrt(ip),
+              list(fit = predictor, se.fit = sqrt(ip),
 	     df = df, residual.scale = sqrt(res.var))
     else predictor
 }
