@@ -1,11 +1,11 @@
 "httpclient" <-
-    function (url, port = 80, error.is.fatal = TRUE, check.MIME.type = TRUE, 
-              file = tempfile(), drop.ctrl.z = TRUE) 
+    function (url, port = 80, error.is.fatal = TRUE, check.MIME.type = TRUE,
+              file = tempfile(), drop.ctrl.z = TRUE)
 {
-    allowed.MIME.types <- c("text/", "application/postscript", 
+    allowed.MIME.types <- c("text/", "application/postscript",
                             "application/x-latex")
     urlel <- strsplit(url, "/")[[1]]
-    if (urlel[1] != "http:") 
+    if (urlel[1] != "http:")
         stop("Not an http:// URL")
     host <- urlel[3]
     rurl <- paste(c("", urlel[-(1:3)]), collapse = "/")
@@ -16,20 +16,20 @@
     head <- read.socket(a, maxlen = 8000)
     b <- strsplit(head, "\n")[[1]]
     if (length(grep("200 OK", b[1])) == 0) {
-        if (error.is.fatal) 
+        if (error.is.fatal)
             stop(b[1])
         else warning(b[1])
         return(file)
     }
-    if (check.MIME.type && length(unlist(lapply(allowed.MIME.types, 
-                                                function(x) grep(x, strsplit(grep("Content-Type:", b, 
-                                                                                  value = T), ":")[[1]][2])))) == 0) {
-        if (error.is.fatal) 
-            stop(grep("Content-Type:", b, value = T))
-        else warning(grep("Content-Type:", b, value = T))
+    if (check.MIME.type && length(unlist(lapply(allowed.MIME.types,
+                                                function(x) grep(x, strsplit(grep("Content-Type:", b,
+                                                                                  value = TRUE), ":")[[1]][2])))) == 0) {
+        if (error.is.fatal)
+            stop(grep("Content-Type:", b, value = TRUE))
+        else warning(grep("Content-Type:", b, value = TRUE))
         return(file)
     }
-    len <- as.numeric(strsplit(grep("Content-Length", b, value = T), 
+    len <- as.numeric(strsplit(grep("Content-Length", b, value = TRUE),
                                ":")[[1]][2])
     getreq <- paste("GET", rurl, "HTTP/1.0\r\nConnection: Keep-Alive\r\nAccept: text/plain\r\n\r\n")
     write.socket(a, getreq)
@@ -37,19 +37,19 @@
     data <- ""
     b <- strsplit(c(head, junk), "\n")
     nn <- length(b[[1]])
-    if (length(b[[2]]) > nn) 
+    if (length(b[[2]]) > nn)
         data <- paste(b[[2]][-(1:nn)], collapse = "\n")
     while (nchar(data) < len) {
-        data <- paste(data, read.socket(a, maxlen = len - nchar(data)), 
+        data <- paste(data, read.socket(a, maxlen = len - nchar(data)),
                       sep = "")
     }
-    if (drop.ctrl.z) 
+    if (drop.ctrl.z)
         data <- gsub("\026", "", data, extended = FALSE)
     cat(data, file = file)
     return(file)
 }
 "read.table.url" <-
-    function (url, method="auto", ...) 
+    function (url, method="auto", ...)
 {
     f<-tempfile()
     if (download.file(url, destfile=f,method=method)==0)
@@ -61,7 +61,7 @@
     return(data)
 }
 "scan.url" <-
-    function (url, file=tempfile(),method="auto", ...) 
+    function (url, file=tempfile(),method="auto", ...)
 {
     if (download.file(url,dest=file,method=method)!=0){
         unlink(file)
@@ -72,7 +72,7 @@
     return(data)
 }
 "source.url" <-
-    function (url,file=tempfile(),...) 
+    function (url,file=tempfile(),...)
 {
     if (download.file(url,dest=file)!=0){
         unlink(file)
@@ -87,8 +87,8 @@
     unlink(file)
 }
 "url.show" <-
-    function (url,  title = url, 
-              delete.file = TRUE, file = tempfile(), method="auto",...) 
+    function (url,  title = url,
+              delete.file = TRUE, file = tempfile(), method="auto",...)
 {
     if (download.file(url, dest = file,method=method)!=0)
         stop("transfer failure")
