@@ -161,8 +161,10 @@ function (topic, package = .packages(), lib.loc = .lib.loc, echo = TRUE,
     if (!is.character(topic))
 	topic <- deparse(topic)[1]
     INDICES <-
-            if(missing(lib.loc)) .path.package(package)
-            else system.file(pkg = package, lib = lib.loc)
+        if(missing(lib.loc))
+            c(.path.package(package, TRUE),
+              system.file(pkg = package, lib = lib.loc))
+        else system.file(pkg = package, lib = lib.loc)
     file <- index.search(topic, INDICES, "AnIndex", "R-ex")
     if (file == "") {
 	warning(paste("No help file found for `", topic, "'", sep = ""))
