@@ -1,7 +1,7 @@
 acf <-
     function (x, lag.max = NULL,
               type = c("correlation", "covariance", "partial"),
-              plot = TRUE, na.action = na.fail, ...)
+              plot = TRUE, na.action = na.fail, demean= TRUE, ...)
 {
     type <- match.arg(type)
     if(type == "partial") {
@@ -21,22 +21,10 @@ acf <-
         lag.max <- floor(10 * (log10(sampleT) - log10(nser)))
     lag.max <- min(lag.max, sampleT - 1)
     if (lag.max < 1) stop("lag.max must be at least 1")
-    x <- sweep(x, 2, apply(x, 2, mean))
+    if(demean) x <- sweep(x, 2, apply(x, 2, mean))
     lag <- matrix(1, nser, nser)
     lag[lower.tri(lag)] <- -1
     acf <- array(NA, c(lag.max + 1, nser, nser))
-#    xp <- rbind(x, matrix(0, ncol = nser,
-#                          nrow = nextn(sampleT + lag.max) - sampleT))
-#    for (i in 1:nser) for (j in 1:nser) {
-#        acf[, i, j] <- convolve(xp[, i], xp[, j])[1:(lag.max + 1)]/sampleT
-#    }
-#     if (type == "correlation") {
-#         if(nser > 1) {
-#             var0 <- diag(acf[1, , ])
-#             acf0 <- sqrt(var0 %*% t(var0))
-#             acf <- sweep(acf, c(2, 3), acf0, "/")
-#         } else acf <- acf/acf[1, , ]
-#     }
     acf <- array(.C("acf",
                     as.double(x), as.integer(sampleT), as.integer(nser),
                     as.integer(lag.max), as.integer(type=="correlation"),
@@ -74,8 +62,8 @@ pacf.default <- function(x, lag.max = NULL, plot = TRUE,
         lag.max <- floor(10 * (log10(sampleT)))
     lag.max <- min(lag.max, sampleT - 1)
     if (lag.max < 1) stop("lag.max must be at least 1")
-    x <- scale(x, T, F)
-    acf <- drop(acf(x, lag.max = lag.max, plot=F)$acf)
+    x <- scale(x, TRUE, FALSE)
+    acf <- drop(acf(x, lag.max = lag.max, plot = FALSE)$acf)
     pacf <- array(.C("uni_pacf",
                as.double(acf),
                pacf = double(lag.max),
@@ -177,7 +165,7 @@ ccf <- function(x, y, lag.max = NULL,
         stop("univariate time series only")
     X <- na.action(ts.union(x, y))
     colnames(X) <- c(deparse(substitute(x)), deparse(substitute(y)))
-    acf.out <- acf(X, lag.max = lag.max, plot = F, type = type)
+    acf.out <- acf(X, lag.max = lag.max, plot = FALSE, type = type)
     lag <- c(rev(acf.out$lag[-1,2,1]), 0, acf.out$lag[,1,2])
     y <- c(rev(acf.out$acf[-1,2,1]), 0, acf.out$acf[,1,2])
     acf.out$acf <- array(y, dim=c(length(y),1,1))
