@@ -806,6 +806,17 @@ static SEXP coerceVectorList(SEXP v, SEXPTYPE type)
     return rval;
 }
 
+static SEXP coerceSymbol(SEXP v, SEXPTYPE type)
+{
+    SEXP rval = R_NilValue;	
+    if (type == EXPRSXP) {
+	PROTECT(rval = allocVector(type, 1));
+	VECTOR(rval)[0] = v;
+	UNPROTECT(1);
+    }
+    return rval;
+}
+
 SEXP coerceVector(SEXP v, SEXPTYPE type)
 {
     SEXP ans = R_NilValue;	/* -Wall */
@@ -817,10 +828,10 @@ SEXP coerceVector(SEXP v, SEXPTYPE type)
     case NILSXP:
 	ans = coerceNull(v, type);
 	break;
+#endif
     case SYMSXP:
 	ans = coerceSymbol(v, type);
 	break;
-#endif
     case NILSXP:
     case LISTSXP:
     case LANGSXP:
@@ -936,7 +947,8 @@ static SEXP ascommon(SEXP call, SEXP u, int type)
     if (type == CLOSXP) {
 	return asFunction(u);
     }
-    else if (isVector(u) || isList(u) || isLanguage(u)) {
+    else if (isVector(u) || isList(u) || isLanguage(u)
+	     || (isSymbol(u) && type == EXPRSXP)) {
 	if (NAMED(u))
 	    v = duplicate(u);
 	else v = u;
