@@ -107,7 +107,7 @@ static void fmingr(int n, double *p, double *df, OptStruct OS)
     if (!isNull(OS->R_gcall)) { /* analytical derivatives */
 	PROTECT(x = allocVector(REALSXP, n));
 	for (i = 0; i < n; i++) {
-	    if (!R_FINITE(p[i])) error("non-finite value supplied by nlm");
+	    if (!R_FINITE(p[i])) error("non-finite value supplied by optim");
 	    REAL(x)[i] = p[i] * (OS->parscale[i]);
 	}
 	CADR(OS->R_gcall) = x;
@@ -135,7 +135,7 @@ static void fmingr(int n, double *p, double *df, OptStruct OS)
 		    error("non-finite values encountered in finite-difference calculation");
 		REAL(x)[i] = p[i] * (OS->parscale[i]);
 	    }
-	} else {
+	} else { /* usebounds */
 	    for (i = 0; i < n; i++) {
 		epsused = eps = OS->ndeps[i];
 		tmp = p[i]  + eps;
@@ -456,6 +456,8 @@ vmmin(int n0, double *b, double *Fmin, int maxit, int trace, int *mask,
     double D1, D2;
     int   n, *l;
 
+    if (nREPORT <= 0)
+	error("REPORT must be > 0 (method = \"BFGS\")");
     l = (int *) R_alloc(n0, sizeof(int));
     n = 0;
     for (i = 0; i < n0; i++) if (mask[i]) l[n++] = i;
@@ -466,7 +468,8 @@ vmmin(int n0, double *b, double *Fmin, int maxit, int trace, int *mask,
     c = vect(n);
     B = Lmatrix(n);
     f = fminfn(n, b, OS);
-    if (!R_FINITE(f)) error("initial value in vmmin is not finite");
+    if (!R_FINITE(f))
+	error("initial value in vmmin is not finite");
     if (trace) Rprintf("initial  value %f \n", f);
     *Fmin = f;
     funcount = gradcount = 1;
@@ -546,7 +549,8 @@ vmmin(int n0, double *b, double *Fmin, int maxit, int trace, int *mask,
 		    D2 = 1.0 + D2 / D1;
 		    for (i = 0; i < n; i++) {
 			for (j = 0; j <= i; j++)
-			    B[i][j] += (D2 * t[i] * t[j] - X[i] * t[j] - t[i] * X[j]) / D1;
+			    B[i][j] += (D2 * t[i] * t[j]
+					- X[i] * t[j] - t[i] * X[j]) / D1;
 		    }
 		} else {	/* D1 < 0 */
 		    ilast = gradcount;
@@ -563,9 +567,8 @@ vmmin(int n0, double *b, double *Fmin, int maxit, int trace, int *mask,
 	    else ilast = gradcount;
 	    /* Resets unless has just been reset */
 	}
-	if ((iter % nREPORT == 0) && trace) {
+	if (trace && (iter % nREPORT == 0))
 	    Rprintf("iter%4d value %f\n", iter, f);
-	}
 	if (iter >= maxit) break;
 	if (gradcount - ilast > 2 * n)
 	    ilast = gradcount;	/* periodic restart */
@@ -583,6 +586,7 @@ vmmin(int n0, double *b, double *Fmin, int maxit, int trace, int *mask,
 #define big             1.0e+35   /*a very large number*/
 
 
+/* Nelder-Mead */
 static
 void nmmin(int n, double *Bvec, double *X, double *Fmin,
 	   int *fail, double abstol, double intol, OptStruct OS,
@@ -591,7 +595,7 @@ void nmmin(int n, double *Bvec, double *X, double *Fmin,
 {
     char action[50];
     int C;
-    Boolean calcvert, notcomp = false, shrinkfail = false;
+    Boolean calcvert, shrinkfail = false;
     double convtol, f;
     int funcount=0, H, i, j, L=0;
     int n1=0;
@@ -635,8 +639,6 @@ void nmmin(int n, double *Bvec, double *X, double *Fmin,
 	    for (i = 0; i < n; i++)
 		P[i][j - 1] = Bvec[i];
 
-
-
 	    trystep = step;
 	    while (P[j - 2][j - 1] == Bvec[j - 2]) {
 		P[j - 2][j - 1] = Bvec[j - 2] + trystep;
@@ -654,8 +656,7 @@ void nmmin(int n, double *Bvec, double *X, double *Fmin,
 			for (i = 0; i < n; i++)
 			    Bvec[i] = P[i][j];
 			f = fminfn(n, Bvec, OS);
-			if (notcomp)
-			    f = big;
+			if (!R_FINITE(f)) f = big;
 			funcount++;
 			P[n1 - 1][j] = f;
 		    }
@@ -720,12 +721,12 @@ void nmmin(int n, double *Bvec, double *X, double *Fmin,
 			P[n1 - 1][H - 1] = VR;
 		    }
 		} else {
-		    strcpy(action, "HI-REDUCTION    ");
+		    strcpy(action, "HI-REDUCTION   ");
 		    if (VR < VH) {
 			for (i = 0; i < n; i++)
 			    P[i][H - 1] = Bvec[i];
 			P[n1 - 1][H - 1] = VR;
-			strcpy(action, "LO-REDUCTION    ");
+			strcpy(action, "LO-REDUCTION   ");
 		    }
 
 		    for (i = 0; i < n; i++)
@@ -794,29 +795,19 @@ void cgmin(int n, double *Bvec, double *X, double *Fmin, int *fail,
     double newstep, oldstep, setstep, steplength=1.0;
     double tol, TEMP;
 
-    if (trace) Rprintf("  Conjugate gradients function minimiser\n");
-
-    c = vect(n); g = vect(n); t = vect(n);
-
-    setstep = 1.7;
-    if (trace)
+    if (trace) {
+	Rprintf("  Conjugate gradients function minimiser\n");
 	switch (type) {
-
-	case 1:
-	    Rprintf("Method: Fletcher Reeves\n");
-	    break;
-
-	case 2:
-	    Rprintf("Method: Polak Ribiere\n");
-	    break;
-
-	case 3:
-	    Rprintf("Method: Beale Sorenson\n");
-	    break;
-
+	case 1:	    Rprintf("Method: Fletcher Reeves\n");	break;
+	case 2:	    Rprintf("Method: Polak Ribiere\n");		break;
+	case 3:	    Rprintf("Method: Beale Sorenson\n");	break;
 	default:
 	    error("unknown type in CG method of optim");
 	}
+    }
+    c = vect(n); g = vect(n); t = vect(n);
+
+    setstep = 1.7;
     *fail = 0;
     cyclimit = n;
     tol = intol * n * sqrt(intol);
@@ -957,6 +948,7 @@ void cgmin(int n, double *Bvec, double *X, double *Fmin, int *fail,
     *grcount = gradcount;
 }
 
+/* from ../appl/lbfgsb.c : */
 void setulb(int n, int m, double *x, double *l, double *u, int *nbd,
 	    double *f, double *g, double factr, double *pgtol,
 	    double *wa, int * iwa, char *task, int iprint,
