@@ -183,7 +183,7 @@ static void printStringVector(SEXP * x, int n, int quote, int index)
 	    else
 		width = 0;
 	}
-	Rprintf("%*s%s", R_print.gap, "", EncodeString(CHAR(x[i]), w, quote, adj_left));
+	Rprintf("%*s%s", R_print.gap, "", EncodeString(CHAR(x[i]), w, quote, Rprt_adj_left));
 	width += w + R_print.gap;
     }
     Rprintf("\n");
@@ -255,7 +255,7 @@ static void printNamedLogicalVector(int * x, int n, SEXP * names)
     for (i = 0; i < nlines; i++) {
 	if (i) Rprintf("\n");
 	for (j = 0; j < nperline && (k = i * nperline + j) < n; j++) {
-	    Rprintf("%s%*s", EncodeString(CHAR(names[k]), w, 0, adj_right),
+	    Rprintf("%s%*s", EncodeString(CHAR(names[k]), w, 0, Rprt_adj_right),
 		    R_print.gap, "");
 	}
 	Rprintf("\n");
@@ -281,7 +281,7 @@ static void printNamedIntegerVector(int * x, int n, SEXP * names)
     for (i = 0; i < nlines; i++) {
 	if (i) Rprintf("\n");
 	for (j = 0; j < nperline && (k = i * nperline + j) < n; j++) {
-	    Rprintf("%s%*s", EncodeString(CHAR(names[k]), w, 0, adj_right),
+	    Rprintf("%s%*s", EncodeString(CHAR(names[k]), w, 0, Rprt_adj_right),
 		    R_print.gap, "");
 	}
 	Rprintf("\n");
@@ -306,7 +306,7 @@ static void printNamedRealVector(double * x, int n, SEXP * names)
     for (i = 0; i < nlines; i++) {
 	if (i) Rprintf("\n");
 	for (j = 0; j < nperline && (k = i * nperline + j) < n; j++) {
-	    Rprintf("%s%*s", EncodeString(CHAR(names[k]), w, 0, adj_right),
+	    Rprintf("%s%*s", EncodeString(CHAR(names[k]), w, 0, Rprt_adj_right),
 		    R_print.gap, "");
 	}
 	Rprintf("\n");
@@ -332,7 +332,7 @@ static void printNamedComplexVector(Rcomplex *x, int n, SEXP *names)
     for (i = 0; i < nlines; i++) {
 	if (i) Rprintf("\n");
 	for (j = 0; j < nperline && (k = i * nperline + j) < n; j++) {
-	    Rprintf("%s%*s", EncodeString(CHAR(names[k]), w, 0, adj_right),
+	    Rprintf("%s%*s", EncodeString(CHAR(names[k]), w, 0, Rprt_adj_right),
 		    R_print.gap, "");
 	}
 	Rprintf("\n");
@@ -373,12 +373,12 @@ static void printNamedStringVector(SEXP * x, int n, int quote, SEXP * names)
     for (i = 0; i < nlines; i++) {
 	if (i) Rprintf("\n");
 	for (j = 0; j < nperline && (k = i * nperline + j) < n; j++) {
-	    Rprintf("%s%*s", EncodeString(CHAR(names[k]), w, 0, adj_right),
+	    Rprintf("%s%*s", EncodeString(CHAR(names[k]), w, 0, Rprt_adj_right),
 		    R_print.gap, "");
 	}
 	Rprintf("\n");
 	for (j = 0; j < nperline && (k = i * nperline + j) < n; j++)
-	    Rprintf("%s%*s", EncodeString(CHAR(x[k]), w, quote, adj_right),
+	    Rprintf("%s%*s", EncodeString(CHAR(x[k]), w, quote, Rprt_adj_right),
 		    R_print.gap, "");
     }
     Rprintf("\n");
