@@ -1,6 +1,8 @@
 /*
  *  R : A Computer Language for Statistical Data Analysis
  *  Copyright (C) 1995, 1996  Robert Gentleman and Ross Ihaka
+ *  Copyright (C) 1997--2000  Robert Gentleman, Ross Ihaka and the
+ *                            R Development Core Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -368,9 +370,10 @@ static SEXP stringSubscript(SEXP s, int ns, int nx, SEXP names, int *stretch)
     /* Ghastly hack!  We attach the new names to the attribute */
     /* slot on the returned subscript vector. */
     if (extra != nnames) {
-	*stretch = extra;
 	ATTRIB(index) = indexnames;
     }
+    if (canstretch)
+	*stretch = extra;
     UNPROTECT(4);    
     return index;
 }
@@ -447,7 +450,7 @@ SEXP makeSubscript(SEXP x, SEXP s, int *stretch)
 	    UNPROTECT(1);
 	    break;
 	case STRSXP:
-	    *stretch = 0;
+	    /* *stretch = 0; */
 	    ans = stringSubscript(s, ns, nx, names, stretch);
 	    break;
 	case SYMSXP:
