@@ -22,7 +22,7 @@
  *    The density of the geometric distribution.
  */
 
-#include "Mathlib.h"
+#include "nmath.h"
 #include "dpq.h"
 
 double dgeom(double x, double p, int give_log)
@@ -33,7 +33,7 @@ double dgeom(double x, double p, int give_log)
     if (p <= 0 || p >= 1) ML_ERR_return_NAN;
 
     if(fabs(x - floor(x + 0.5)) > 1e-7) {
-	warning("non-integer x = %f", x);
+	MATHLIB_WARNING("non-integer x = %f", x);
 	return R_D__0;
     }
     if (x < 0)
