@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA.
  *
  *  SYNOPSIS
  *
@@ -26,7 +26,7 @@
  *    Compute minimum of two integers.
  */
 
-#include "Mathlib.h"
+#include "nmath.h"
 
 int imin2(int x, int y)
 {
