@@ -39,7 +39,7 @@
  *    Vol.30, pp.1-15, 1988.
  */
 
-#include "Mathlib.h"
+#include "nmath.h"
 #include "dpq.h"
 
 static double wprob(double w, double rr, double cc)
