@@ -44,7 +44,7 @@ static char copycontents[30] = "";
 #ifndef min
 #define min(a, b) (((a)<(b))?(a):(b))
 #endif
-#define BOXW(x) ((x<100 && nboxchars==0)?boxw[x]:box_w)
+#define BOXW(x) (min(((x<100 && nboxchars==0)?boxw[x]:box_w), fullwindowWidth-boxw[0]-2*bwidth-2))
 
 
 /*
@@ -306,7 +306,7 @@ void drawwindow()
 
 }
 
-void doHscroll(int oldcol)
+static void doHscroll(int oldcol)
 {
     int i, dw;
     int oldnwide = nwide, oldwindowWidth = windowWidth;
@@ -452,6 +452,7 @@ static int get_col_width(int col)
 	}
 	if(w < 0.5*box_w) w = 0.5*box_w;
 	if(w < 0.8*box_w) w+= 0.1*box_w;
+	if(w > 600) w = 600;
 	return w+8;
     }
     return box_w;
@@ -672,7 +673,7 @@ static SEXP getccol()
     len = LENGTH(CAR(tmp));
     type = TYPEOF(CAR(tmp));
     if (len < wrow) {
-	for (newlen = len * 2 ; newlen < wrow ; newlen *= 2)
+	for (newlen = max(len * 2, 10) ; newlen < wrow ; newlen *= 2)
 	    ;
 	tmp2 = ssNewVector(type, newlen);
 	for (i = 0; i < len; i++)
@@ -768,24 +769,27 @@ static void closerect()
    the print area and print it, left adjusted if necessary; clear the
    area of previous text; */
 
+/* This version will only display 200 chars, but the maximum col width
+   will not allow that many */
 static void printstring(char *ibuf, int buflen, int row, int col, int left)
 {
-    int i, x_pos, y_pos, bw;
-    char buf[45], *pc = buf;
+    int i, x_pos, y_pos, bw, bufw;
+    char buf[201], *pc = buf;
 
     find_coords(row, col, &x_pos, &y_pos);
     if (col == 0) bw = boxw[0]; else bw = BOXW(col+colmin-1);
     cleararea(x_pos + 2, y_pos + 2, bw - 3, box_h - 3);
-    strncpy(buf, ibuf, buflen);
+    bufw = (buflen > 200) ? 200 : buflen;
+    strncpy(buf, ibuf, bufw);
     if(left) {
-	for (i = buflen; i > 1; i--) {
+	for (i = bufw; i > 1; i--) {
 	    if (textwidth(pc, i) < (bw - text_offset)) break;
 	    *(++pc) = '<';
 	}
     } else {
-	for (i = buflen; i > 1; i--) {
+	for (i = bufw; i > 1; i--) {
 	    if (textwidth(buf, i) < (bw - text_offset)) break;
-	    *(pc + i - 2) = '>';
+	    *(buf + i - 2) = '>';
 	}
     }
     drawtext(x_pos + text_offset, y_pos + box_h - text_offset, pc, i);
@@ -1061,12 +1065,21 @@ static void doSpreadKey(int key, DEEvent * event)
 	advancerect(RIGHT);
     else if (iokey == XK_Up)
 	advancerect(UP);
+#ifdef _AIX
+    else if (iokey == XK_Prior) {
+	int i = rowmin - nhigh + 2;
+	jumpwin(colmin, max(1, i));
+    }
+    else if (iokey == XK_Next)
+	jumpwin(colmin, rowmax);
+#else
     else if (iokey == XK_Page_Up) {
 	int i = rowmin - nhigh + 2;
 	jumpwin(colmin, max(1, i));
     }
     else if (iokey == XK_Page_Down)
 	jumpwin(colmin, rowmax);
+#endif
     else if ((iokey == XK_BackSpace) || (iokey == XK_Delete)) {
 	if (clength > 0) {
 	    clength--;
@@ -1157,6 +1170,7 @@ static void doControl(DEEvent * event)
 	    jumpwin(colmin, rowmax);
 	    break;
 	case 'l':
+	    closerect();
 	    for (i = 1 ; i <= min(100, xmaxused); i++)
 		boxw[i] = get_col_width(i);
 	    drawwindow();
